# -*- coding: utf-8 -*-

from simmate.database.base_data_types import BandStructureCalc


class MatprojBandStructure(BandStructureCalc):
    pass
